import {
  getPurchaseDetail,
  savePurchaseInStore,
} from "@/services/purchase";
import { getStoreList } from "@/services/stock";
import { useNavigate, useSearchParams } from "react-router-dom";
import { Card, Descriptions, Button } from "antd";
import { useEffect, useMemo, useState } from "react";
import moment from "moment";
import { floatMultiply, floatDivide } from "@/utils/float";
import useBool from "@/utils/hooks/useBool";

const Item = Descriptions;

export default (props) => {
  const [searchParams] = useSearchParams();
  const id = searchParams.get("id");
  const [storeList, setStoreList] = useState([]);
  const [detail, setDetail] = useState({});
  const navigate = useNavigate();
  const [loading, startLoading, cancelLoading] = useBool();

  const dtStr = useMemo(() => detail.completedDate ? moment(detail.completedDate).format('YYYY-MM-DD'): '', [detail.completedDate]);

  const onSumbit = () => {
    startLoading()
    savePurchaseInStore(id).then(() => {
      cancelLoading()
      setDetail({ ...detail, isInStore: true })
    }).catch(cancelLoading)
  }
  
  useEffect(() => {
    getStoreList({ pageSize: 9999 }).then((res) => {
      setStoreList(res.records || []);
    });
  }, []);

  useEffect(() => {
    if (id) {
      getPurchaseDetail(id).then((res) => {
        setDetail({
          ...res,
          itemsList: res.itemsList?.map((x) => ({
            ...x,
            planUnitPrice: x.planUnitPrice
              ? floatDivide(x.planUnitPrice, 100)
              : null,
            actUnitPrice: x.actUnitPrice
              ? floatDivide(x.actUnitPrice, 100)
              : null,
          })),
        });
      });
    }
  }, [id]);

  return (
    <Card
      title={<div>采购单</div>}
      extra={(
        <>
          <Button
            type="primary"            
            disabled={detail.isInStore || !detail.isCompleted}
            loading={loading}
            onClick={onSumbit}
          >
            入库
          </Button>
          <Button style={{ marginLeft: '2em' }} onClick={() => navigate(-1)}>返回</Button> 
        </>
      )}
    >
      <Descriptions title="基本信息" bordered>
        <Item label="采购时间">{dtStr}</Item>
        <Item label="计划时间">{detail.planDate}</Item>
      </Descriptions>
      <Descriptions title="明细信息" bordered style={{ marginTop: '24px' }} column={5}>
        {
          (detail.itemsList || []).reduce((acc, it, inx) => {

            const store = storeList.filter(x => x.id === it.storeId)[0] || {};
            const planUnitPrice = it.planUnitPrice ? `${it.planUnitPrice} 元` : '-';
            const planAmount = it.planAmount ? `${it.planAmount} ${store.unit}` : '-';
            const actUnitPrice = it.actUnitPrice ? `${it.actUnitPrice} 元` : '-';
            const actAmount = it.actAmount ? `${it.actAmount} ${store.unit}` : '-';

            return acc.concat([
                <Item key={`t-${inx}-1`} label="采购物品名称">{store.name}</Item>,
                <Item key={`t-${inx}-2`} label="计划采购单价">{planUnitPrice}</Item>,
                <Item key={`t-${inx}-3`} label="计划采购数量">{planAmount}</Item>,
                <Item key={`t-${inx}-4`} label="实际采购单价">{actUnitPrice}</Item>,
                <Item key={`t-${inx}-5`} label="实际采购数量">{actAmount}</Item>,
              ]
            )
          }, [])
        }
      </Descriptions>
    </Card>
  );
};
